@@ -16,7 +16,7 @@ try:
 except ImportError:
     import urllib.request as urllib2
 
-__version__ = "0.1.20"
+__version__ = "0.1.21"
 __author__ = "Xiaocong He"
 __all__ = ["device", "Device", "rect", "point", "Selector"]
 
@@ -302,8 +302,8 @@ class AutomatorServer(object):
     """start and quit rpc server on device.
     """
     __jar_files = {
-        "bundle.jar": 'https://github.com/xiaocong/android-uiautomator-jsonrpcserver/blob/release/dist/bundle.jar?raw=true',
-        "uiautomator-stub.jar": "https://github.com/xiaocong/android-uiautomator-jsonrpcserver/blob/release/dist/uiautomator-stub.jar?raw=true"
+        "bundle.jar": "https://github.com/xiaocong/android-uiautomator-jsonrpcserver/releases/download/v0.1.1/bundle.jar",
+        "uiautomator-stub.jar": "https://github.com/xiaocong/android-uiautomator-jsonrpcserver/releases/download/v0.1.1/uiautomator-stub.jar"
     }
 
     def __init__(self, serial=None, local_port=None):
@@ -388,12 +388,15 @@ class AutomatorServer(object):
                 self.uiautomator_process.kill()
             finally:
                 self.uiautomator_process = None
-        out = self.adb.cmd("shell", "ps", "-C", "uiautomator").communicate()[0].decode("utf-8").strip().splitlines()
-        if out:
-            index = out[0].split().index("PID")
-            for line in out[1:]:
-                if len(line.split()) > index:
-                    self.adb.cmd("shell", "kill", "-9", line.split()[index]).wait()
+        try:
+            out = self.adb.cmd("shell", "ps", "-C", "uiautomator").communicate()[0].decode("utf-8").strip().splitlines()
+            if out:
+                index = out[0].split().index("PID")
+                for line in out[1:]:
+                    if len(line.split()) > index:
+                        self.adb.cmd("shell", "kill", "-9", line.split()[index]).wait()
+        except:
+            pass
 
     @property
     def stop_uri(self):
